==> mtlibs-0.0.236-py3-none-any.whl: mtlibs/cli/mtclash.py <==
#!/usr/bin/env python3

"""
README.md

原因：openvpn看起来不太好用，替代方案太多了。
二：主要基于python，在性能特别关键的地方使用nodejs 辅助。
三：理解了python setup.py 相关的部署方式之后，可以很方便的在一个project中管理多个发布包。
四：目前，关键代码已经迁移至：mtxcms中。


## 快速启动(生产版)
```bash
docker pull csrep/mtproxy

# 局域网网关（网络出口）
export GATEWAY_IP=192.168.43.1
# 网段
export DEFAULT_CIDR=192.168.43.0/24
# 创建docker 网络适配器名
export NETWORK_NAME=macvlanname
export DEFAULT_IP=192.168.43.6
export DEFAULT_GATEWAY=192.168.43.1
# 网卡接口名称
export DEFAULT_IF=eth0
export USE_TPROXY=1
# 设置网卡的扎混模式
sudo ip link set ${DEFAULT_IF} promisc on
# 创建docker 网络适配器(一次性)
#docker network create -d macvlan --subnet=${LAN_CIDR} --gateway=${GATEWAY_IP} -o parent=${INTERFACE} ${NETWORK_NAME}
docker run -it \
    --name mtproxy_gateway \
    --cap-add=NET_ADMIN \
    --restart unless-stopped \
    --network ${NETWORK_NAME} \
    --ip ${DEFAULT_IP} \
    csrep/mtproxy
```


## 重要备注
- 实际实践发现， docker-compose 中的网络配置macvlan以及网卡杂混模式下，另外的客户端IP的设置就算没有严格配置网段的，都能通过clash配置的网关正确处理流量连接外网。
  这个特性非常方便。可以在clash中配置规则，根据元IP网段来规划出站路径。
  
## 启动
```bash
dc up mtproxy_gateway -d
```


## 参考项目：
- https://github.com/fei-ke/clash-tproxy


## 相关环境变量
NETWORK=gapi
DOCKER_COMPOSE_ARGS=-f docker-compose.yml
#HTTP_PROXY=http://192.168.43.1:7890
#HTTPS_PROXY=http://192.168.43.1:7890

DEFAULT_IF=eth0
DEFAULT_GATEWAY=192.168.43.1
DEFAULT_IP=192.168.43.99
DEFAULT_CIDR=192.168.43.0/24
DEFAULT_DNS=192.168.43.1
TPROXY_IP=192.168.43.6
USE_TPROXY=1

# tor 外部代理
TOR_SOCKS5PROXY=192.168.43.1:7894
"""



import os
import sys
import subprocess
import shlex
from pathlib import Path
from dotenv import load_dotenv, find_dotenv
import logging
logging.basicConfig(level = logging.DEBUG,format = '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)

ENV_FILE = find_dotenv()
if ENV_FILE:
    load_dotenv(ENV_FILE)

load_dotenv(".env")


def setup_iptables_for_clash_tproxy():
    """设置iptabls"""
    script = """
ip rule add fwmark 0x1 lookup 100
ip route add local default dev lo table 100
iptables -t mangle -N clash
iptables -t mangle -A clash -d 0.0.0.0/8 -j RETURN
iptables -t mangle -A clash -d 10.0.0.0/8 -j RETURN
iptables -t mangle -A clash -d 127.0.0.0/8 -j RETURN
iptables -t mangle -A clash -d 169.254.0.0/16 -j RETURN
iptables -t mangle -A clash -d 172.16.0.0/12 -j RETURN
iptables -t mangle -A clash -d 192.168.0.0/16 -j RETURN
iptables -t mangle -A clash -d 224.0.0.0/4 -j RETURN
iptables -t mangle -A clash -d 240.0.0.0/4 -j RETURN
iptables -t mangle -A clash -p udp --dport 53 -j RETURN
iptables -t mangle -A clash -p tcp -j TPROXY --on-port 7893 --tproxy-mark 0x1
iptables -t mangle -A clash -p udp -j TPROXY --on-port 7893 --tproxy-mark 0x1
iptables -t mangle -A PREROUTING -p tcp -j clash
iptables -t mangle -A PREROUTING -p udp -j clash
iptables -t nat -I POSTROUTING -o ${DEFAULT_IF} -j MASQUERADE
"""
    os.system(script)
    
def start_clash():
    """启动clash"""
    # config_file = os.path.join(os.getcwd(), "data/clash/config-tproxy.yml")
    
    logger.info(f"当前脚本路径:{__file__}")
    
    package_dir = str(Path(__file__).parent)
    clash_config_path = str(Path(__file__).parent.joinpath("../data/clash/config-tproxy.yml"))
    logger.info(f"当前脚本文件夹路径路径:{package_dir}")
    
    # config_file = os.path.join(os.getcwd(), "data/clash/config-tproxy.yml")
    os.system(f"clash -f {clash_config_path}")

def main():
    logger.info("mtclash 本地代理网关")
    setup_iptables_for_clash_tproxy()
    start_clash()
    logger.info("就绪")

if __name__ == "__main__":
    main()

==> mtlibs-0.0.237-py3-none-any.whl: mtlibs/cli/mtclash.py <==
#!/usr/bin/env python3

"""
README.md

原因：openvpn看起来不太好用，替代方案太多了。
二：主要基于python，在性能特别关键的地方使用nodejs 辅助。
三：理解了python setup.py 相关的部署方式之后，可以很方便的在一个project中管理多个发布包。
四：目前，关键代码已经迁移至：mtxcms中。


## 快速启动(生产版)
```bash
docker pull csrep/mtproxy

# 局域网网关（网络出口）
export GATEWAY_IP=192.168.43.1
# 网段
export DEFAULT_CIDR=192.168.43.0/24
# 创建docker 网络适配器名
export NETWORK_NAME=macvlanname
export DEFAULT_IP=192.168.43.6
export DEFAULT_GATEWAY=192.168.43.1
# 网卡接口名称
export DEFAULT_IF=eth0
export USE_TPROXY=1
# 设置网卡的扎混模式
sudo ip link set ${DEFAULT_IF} promisc on
# 创建docker 网络适配器(一次性)
#docker network create -d macvlan --subnet=${LAN_CIDR} --gateway=${GATEWAY_IP} -o parent=${INTERFACE} ${NETWORK_NAME}
docker run -it \
    --name mtproxy_gateway \
    --cap-add=NET_ADMIN \
    --restart unless-stopped \
    --network ${NETWORK_NAME} \
    --ip ${DEFAULT_IP} \
    csrep/mtproxy
```


## 重要备注
- 实际实践发现， docker-compose 中的网络配置macvlan以及网卡杂混模式下，另外的客户端IP的设置就算没有严格配置网段的，都能通过clash配置的网关正确处理流量连接外网。
  这个特性非常方便。可以在clash中配置规则，根据元IP网段来规划出站路径。
  
## 启动
```bash
dc up mtproxy_gateway -d
```


## 参考项目：
- https://github.com/fei-ke/clash-tproxy


## 相关环境变量
NETWORK=gapi
DOCKER_COMPOSE_ARGS=-f docker-compose.yml
#HTTP_PROXY=http://192.168.43.1:7890
#HTTPS_PROXY=http://192.168.43.1:7890

DEFAULT_IF=eth0
DEFAULT_GATEWAY=192.168.43.1
DEFAULT_IP=192.168.43.99
DEFAULT_CIDR=192.168.43.0/24
DEFAULT_DNS=192.168.43.1
TPROXY_IP=192.168.43.6
USE_TPROXY=1

# tor 外部代理
TOR_SOCKS5PROXY=192.168.43.1:7894
"""



import os
import sys
import subprocess
import shlex
from pathlib import Path
from dotenv import load_dotenv, find_dotenv
import logging
logging.basicConfig(level = logging.DEBUG,format = '%(asctime)s - %(name)s - %(levelname)s - %(message)s')
logger = logging.getLogger(__name__)

ENV_FILE = find_dotenv()
if ENV_FILE:
    load_dotenv(ENV_FILE)

load_dotenv(".env")


def setup_iptables_for_clash_tproxy():
    """设置iptabls"""
    script = """
ip rule add fwmark 0x1 lookup 100
ip route add local default dev lo table 100
iptables -t mangle -N clash
iptables -t mangle -A clash -d 0.0.0.0/8 -j RETURN
iptables -t mangle -A clash -d 10.0.0.0/8 -j RETURN
iptables -t mangle -A clash -d 127.0.0.0/8 -j RETURN
iptables -t mangle -A clash -d 169.254.0.0/16 -j RETURN
iptables -t mangle -A clash -d 172.16.0.0/12 -j RETURN
iptables -t mangle -A clash -d 192.168.0.0/16 -j RETURN
iptables -t mangle -A clash -d 224.0.0.0/4 -j RETURN
iptables -t mangle -A clash -d 240.0.0.0/4 -j RETURN
iptables -t mangle -A clash -p udp --dport 53 -j RETURN
iptables -t mangle -A clash -p tcp -j TPROXY --on-port 7893 --tproxy-mark 0x1
iptables -t mangle -A clash -p udp -j TPROXY --on-port 7893 --tproxy-mark 0x1
iptables -t mangle -A PREROUTING -p tcp -j clash
iptables -t mangle -A PREROUTING -p udp -j clash
iptables -t nat -I POSTROUTING -o ${DEFAULT_IF} -j MASQUERADE
"""
    os.system(script)
    
def start_clash():
    """启动clash"""
    # config_file = os.path.join(os.getcwd(), "data/clash/config-tproxy.yml")
    
    logger.info(f"当前脚本路径:{__file__}")
    
    package_dir = str(Path(__file__).parent)
    clash_config_path = str(Path(__file__).parent.parent.joinpath("data/clash/config-tproxy.yml"))
    logger.info(f"当前脚本文件夹路径路径:{package_dir}")
    
    # config_file = os.path.join(os.getcwd(), "data/clash/config-tproxy.yml")
    os.system(f"clash -f {clash_config_path}")

def main():
    logger.info("mtclash 本地代理网关")
    setup_iptables_for_clash_tproxy()
    start_clash()
    logger.info("就绪")

if __name__ == "__main__":
    main()
